#!/usr/bin/env python3

"""
This demo prints the distance in cm between the sensor and the closest detected object in cm;
it then yields the following output in to the terminal:
<int: detection distance>
where min(detection distance) = 70
"""

import functools
import signal_frame_utils as sfu
import x4_utils as x4

print = functools.partial(print, flush=True)

def print_distance(signal_frame):
    """
    Prints for each frame the distance between the sensor and the closest detected object;
    it does so in the following format:
    <int: detection distance>

    Args:
        signal_frame: SignalFrame object (e.g. extracted by `read_signal_stream` function)

    Returns: None
    """

    power = x4.get_power(signal_frame)
    if power is not None:   # Not every frame contains data
        print(x4.get_distance(power))


if __name__ == '__main__':
    sfu.read_signal_stream(print_distance)
