#!/usr/bin/env python3

"""
This demo prints whether the sensor is detecting anything or not; it then yields
the following output in the terminal:
<int: frame> <string: detection status>
where 'detection status' is either 'PRESENCE' or 'NO PRESENCE'.
"""

import functools
import signal_frame_utils as sfu
import x4_utils as x4

print = functools.partial(print, flush=True)

def print_presence(signal_frame):
    """
    Prints for each frame whether the sensor is currently detecting anything; it does so in the
    following format:
    <int: frame> <string: detection status>
    where 'detection status' is either 'PRESENCE' or 'NO PRESENCE'.

    Args:
        signal_frame: SignalFrame object (e.g. extracted by `read_signal_stream` function)

    Returns: None
    """

    presence = x4.get_presence(signal_frame)
    if presence is not None:    # Not every frame contains data
        print(f"{presence['sequence_number']} {STATE_TEXT[presence['detection']]}")


if __name__ == '__main__':
    STATE_TEXT = ['NO PRESENCE', 'PRESENCE']
    sfu.read_signal_stream(print_presence)
